# Dimcli

Dimcli is a Python client for accessing the Dimensions Analytics API. It makes it easier to authenticate against the API, send queries to it and process the JSON data being returned.  

For more information see the [Getting Started with Dimcli](https://digital-science.github.io/dimcli/getting-started.html) tutorial.
 
![dimcli_animation](https://raw.githubusercontent.com/digital-science/dimcli/master/static/dimcli_animated.gif)

Current version: see [pypi homepage](https://pypi.org/project/dimcli/). Source code hosted on [github](https://github.com/digital-science/dimcli). 



## Comments, bug reports

Dimcli lives on [Github](https://github.com/digital-science/dimcli/). You can file [issues]([issues](https://github.com/digital-science/dimcli/issues/new)) or pull requests there. Suggestions, pull requests and improvements welcome!
